//
// "$Id: adjuster.cxx 4886 2006-03-30 09:55:32Z fabien $"
//
// Adjuster test program for the Fast Light Tool Kit (FLTK).
//
// Copyright 1998-2006 by Bill Spitzak and others.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems to "fltk-bugs@fltk.org".
//

#include <fltk/run.h>
#include <fltk/Window.h>
#include <fltk/Adjuster.h>
#include <fltk/Button.h>
#include <stdlib.h>
#include <stdio.h>

fltk::Adjuster* a1;
fltk::Adjuster* a2;
fltk::Group* widget1; // Groups used as generic visible widgets
fltk::Group* widget2;

void adjcb(fltk::Adjuster* a, void* v);


int main(int argc, char** argv)
{
  fltk::Window* w;

  w = new fltk::Window(325, 105, "fltk::Adjuster");
  w->begin();
  {  
    
    // We'll play with two adjusters and two widgets to
    // show the values.
    
    char buf1[32] = {0};
    char buf2[32] = {0};
  
    a1 = new fltk::Adjuster(90, 31, 67, 25);
    a1->callback((fltk::Callback*)adjcb, (void*)(&widget1));
  
    fltk::Adjuster* a2 = new fltk::Adjuster(280, 10, 24, 75);
    a2->set_vertical();
    a2->callback((fltk::Callback*)adjcb, (void*)(&widget2));
  
    // we will use a group as a label display but we'll give
    // it a read/write buffer we can update with Adjuster
    // outputs.  Basically it's a button that doesn't 'click'.
    
    widget1 = new fltk::Group(20, 32, 70, 25, buf1);
    
    // and by the time we're done decorating it, you'd never
    // know it was just a Group. :-)
    
    widget1->box(fltk::DOWN_BOX);
    widget1->color((fltk::Color)0xffffff00);
    widget1->align(fltk::ALIGN_INSIDE);
  
    // and another one.
    widget2 = new fltk::Group(208, 33, 70, 25, buf2);
    widget2->box(fltk::DOWN_BOX);
    widget2->color((fltk::Color)0xffffff00);
    widget2->align(fltk::ALIGN_INSIDE);
  }
  w->end();
  w->show();
  fltk::run();
  return 0;
}


void adjcb(fltk::Adjuster* a, void* pw)
{
  // cast the group pointer to a generic widget so we can 
  // write to its label.
  
  fltk::Widget* b = *(fltk::Widget**)pw;
  
  // Note, we used the address of the pointer, and fetched
  // it's value here so it doesn't matter what order they
  // are created in.
  
  // we put read/write memory in the label, not 'const' char*
  // so we can write to it here after we fetch it.
  
  char* text = (char*)b->label();
  
  // let the adjuster format its own output into the buffer
  // and re-assign it to the label and redraw.
  a->format(text);
  b->label(text);
  b->redraw_label();

}


//
// End of "$Id: adjuster.cxx 4886 2006-03-30 09:55:32Z fabien $".
//
