//#include <fltk/fl_config.h>

#include <fltk/x.h>
#include <X11/X.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#ifdef _WIN32
#include <windows.h>
#endif

#ifndef PATH_MAX
#define PATH_MAX 128
#endif

void dbg(){}

#ifndef _WIN32

/// rs->

#include <fltk/Preferences.h>
class Fl_Config : public fltk::Preferences
{
  public:
    Fl_Config(char* name);
    
    // returns 0 on success
//    int set(char* key, char* value);
    
    // get human readable error report
    char* strerror() {return _strerror;};
  private:
    char _strerror[256];
};

Fl_Config::Fl_Config(char* name) : fltk::Preferences(SYSTEM, "config", name)
{
  sprintf(_strerror, "%s", "Unknown error (if any\?\?\?)");
}

/// <-rs


static int _getprop(XWindow w, Atom a, Atom type, long len, unsigned char **p){
  Atom real_type;
  int format;
  unsigned long n, extra;
  int status;
  
  status = XGetWindowProperty(fltk::xdisplay, w, a, 0L, len, False, type, &real_type, &format, &n, &extra, p);
  if (status != Success || *p == 0)
    return -1;
  if (n == 0)
    XFree((char*) *p);
  return n;
}

// Stolen from KDE!
static bool getSimpleProperty(XWindow w, Atom a, long &result){
  long *p = 0;

  if (_getprop(w, a, a, 1L, (unsigned char**)&p) <= 0){
    return false;
  }

  result = p[0];
  XFree((char *) p);
  return true;
}
#endif

const char* pname;

void usage() {
  fprintf(stderr, "%s: Usage- %s <scheme>\n", pname, pname);
  exit(1);
}

int main(int argc, char* argv[]) {
  dbg();
  pname = argv[0];
  if (argc != 2) usage();

  char scheme[PATH_MAX];
  strncpy(scheme, argv[1], sizeof(scheme));

  Fl_Config flconfig("flconfig");
  int r;

  if ( (r = flconfig.set("default/scheme", scheme)) ) {
    fprintf(stderr, "%s: Error- Cannot set default scheme.\n", pname);
//    fprintf(stderr, "%s: Error- %s.\n", pname, flconfig.strerror());
    exit(3);
  }

#ifndef _WIN32
  // stolen from KDE!
  fltk::open_display();
  int screen = DefaultScreen(fltk::xdisplay);
  XWindow root = RootWindow(fltk::xdisplay, screen);

  XEvent ev;
  unsigned int i, nrootwins;
  XWindow dw1, dw2, *rootwins;

  XQueryTree(fltk::xdisplay, root, &dw1, &dw2, &rootwins, &nrootwins);

  Atom a = XInternAtom(fltk::xdisplay, "FLTK_STYLE_WINDOW", False);
  Atom Scheme = XInternAtom(fltk::xdisplay, "FLTKChangeScheme", False);

  for (i = 0; i < nrootwins; i++) {
    long result = 0;
    getSimpleProperty(rootwins[i],a, result);
    if (result) {
      ev.xclient.type = ClientMessage;
      ev.xclient.display = fltk::xdisplay;
      ev.xclient.window = rootwins[i];
      ev.xclient.message_type = Scheme;
      ev.xclient.format = 32;

      XSendEvent(fltk::xdisplay, rootwins[i] , False, 0L, &ev);
    }
  }

  XFlush(fltk::xdisplay);

  XFree((char *) rootwins);
#else
  // Need to figure out how to do this for Windows...
  // But why bother, we already handle Windows style change events.
#endif
}

